@@ -140,7 +140,7 @@ set_return_ffi_arg_from_giargument (GITypeInfo  *ret_type,
 
             if (interface_type == GI_INFO_TYPE_ENUM ||
                 interface_type == GI_INFO_TYPE_FLAGS)
-                *(ffi_sarg *) result = return_value->v_int;
+                *(ffi_sarg *) result = return_value->v_long;
             else
                 *(ffi_arg *) result = (ffi_arg) return_value->v_pointer;
 
@@ -310,19 +310,16 @@ static void gjs_callback_closure(ffi_cif* cif G_GNUC_UNUSED, void* result,
                     goto out;
                 break;
             }
-            case PARAM_NORMAL: {
+            case PARAM_NORMAL:
                 if (!jsargs.growBy(1))
                     g_error("Unable to grow vector");
 
-                GIArgument* arg = args[i + c_args_offset];
-                if (g_arg_info_get_direction(&arg_info) == GI_DIRECTION_INOUT)
-                    arg = *reinterpret_cast<GIArgument**>(arg);
-
                 if (!gjs_value_from_g_argument(context, jsargs[n_jsargs++],
-                                               &type_info, arg, false))
+                                               &type_info,
+                                               args[i + c_args_offset],
+                                               false))
                     goto out;
                 break;
-            }
             case PARAM_CALLBACK:
                 /* Callbacks that accept another callback as a parameter are not
                  * supported, see gjs_callback_trampoline_new() */
@@ -378,21 +375,6 @@ static void gjs_callback_closure(ffi_cif* cif G_GNUC_UNUSED, void* result,
             break;
         }
     } else {
-        bool is_array = rval.isObject();
-        if (!JS_IsArrayObject(context, rval, &is_array))
-            goto out;
-
-        if (!is_array) {
-            JSFunction* fn = gjs_closure_get_callable(trampoline->js_function);
-            gjs_throw(context,
-                      "Function %s (%s.%s) returned unexpected value, "
-                      "expecting an Array",
-                      gjs_debug_string(JS_GetFunctionDisplayId(fn)).c_str(),
-                      g_base_info_get_namespace(trampoline->info),
-                      g_base_info_get_name(trampoline->info));
-            goto out;
-        }
-
         JS::RootedValue elem(context);
         JS::RootedObject out_array(context, rval.toObjectOrNull());
         gsize elem_idx = 0;
@@ -569,7 +551,11 @@ GjsCallbackTrampoline* gjs_callback_trampoline_new(
             interface_info = g_type_info_get_interface(&type_info);
             interface_type = g_base_info_get_type(interface_info);
             if (interface_type == GI_INFO_TYPE_CALLBACK) {
-                gjs_throw(context, "Callback accepts another callback as a parameter. This is not supported");
+                gjs_throw(context,
+                          "%s %s accepts another callback as a parameter. This "
+                          "is not supported",
+                          is_vfunc ? "VFunc" : "Callback",
+                          g_base_info_get_name(callable_info));
                 g_base_info_unref(interface_info);
                 return NULL;
             }
@@ -583,7 +569,11 @@ GjsCallbackTrampoline* gjs_callback_trampoline_new(
 
                     g_callable_info_load_arg(trampoline->info, array_length_pos, &length_arg_info);
                     if (g_arg_info_get_direction(&length_arg_info) != direction) {
-                        gjs_throw(context, "Callback has an array with different-direction length arg, not supported");
+                        gjs_throw(context,
+                                  "%s %s has an array with different-direction "
+                                  "length argument. This is not supported",
+                                  is_vfunc ? "VFunc" : "Callback",
+                                  g_base_info_get_name(callable_info));
                         return NULL;
                     }
 
