@@ -135,14 +135,12 @@ class GjsContextPrivate {
 
  public:
     /* Retrieving a GjsContextPrivate from JSContext or GjsContext */
-    GJS_USE static GjsContextPrivate* from_cx(JSContext* cx) {
+    GJS_USE GJS_ALWAYS_INLINE static GjsContextPrivate* from_cx(JSContext* cx) {
         return static_cast<GjsContextPrivate*>(JS_GetContextPrivate(cx));
     }
     GJS_USE static GjsContextPrivate* from_object(GObject* public_context);
     GJS_USE static GjsContextPrivate* from_object(GjsContext* public_context);
-    GJS_USE static GjsContextPrivate* from_current_context(void) {
-        return from_object(gjs_context_get_current());
-    }
+    GJS_USE static GjsContextPrivate* from_current_context();
 
     GjsContextPrivate(JSContext* cx, GjsContext* public_context);
     ~GjsContextPrivate(void);
