@@ -31,6 +31,8 @@
 
 #ifdef HAVE_UNISTD_H
 #    include <unistd.h>  // for getpid
+#elif defined (_WIN32)
+#    include <process.h>
 #endif
 
 #include <new>
@@ -285,7 +287,7 @@ gjs_context_class_init(GjsContextClass *klass)
 #ifdef G_OS_WIN32
         extern HMODULE gjs_dll;
         char *basedir = g_win32_get_package_installation_directory_of_module (gjs_dll);
-        char *priv_typelib_dir = g_build_filename (basedir, "lib", "girepository-1.0", NULL);
+        char *priv_typelib_dir = g_build_filename (basedir, "lib", "gjs", "girepository-1.0", NULL);
         g_free (basedir);
 #else
         char *priv_typelib_dir = g_build_filename (PKGLIBDIR, "girepository-1.0", NULL);
