@@ -21,15 +21,12 @@
  * IN THE SOFTWARE.
  */
 
-#ifndef GJS_GLOBAL_H
-#define GJS_GLOBAL_H
+#ifndef GJS_GLOBAL_H_
+#define GJS_GLOBAL_H_
 
-#include <glib.h>
+#include "gjs/jsapi-wrapper.h"
 
 #include "gjs/macros.h"
-#include "jsapi-wrapper.h"
-
-G_BEGIN_DECLS
 
 typedef enum {
     GJS_GLOBAL_SLOT_IMPORTS,
@@ -68,8 +65,6 @@ void gjs_set_global_slot(JSContext    *context,
                          GjsGlobalSlot slot,
                          JS::Value     value);
 
-G_END_DECLS
-
 JS::Value gjs_get_global_slot(JSContext* cx, GjsGlobalSlot slot);
 
-#endif  /* GJS_GLOBAL_H */
+#endif  // GJS_GLOBAL_H_
