@@ -21,18 +21,18 @@
  * IN THE SOFTWARE.
  */
 
-#include <config.h>
+#include <stdarg.h>
 
-#include "gi/gerror.h"
+#include <glib.h>
+
+#include "gjs/jsapi-wrapper.h"
+
+#include "gjs/atoms.h"
 #include "gjs/context-private.h"
-#include "jsapi-util.h"
-#include "jsapi-wrapper.h"
+#include "gjs/jsapi-util.h"
+#include "util/log.h"
 #include "util/misc.h"
 
-#include <util/log.h>
-
-#include <string.h>
-
 /*
  * See:
  * https://bugzilla.mozilla.org/show_bug.cgi?id=166436
@@ -95,7 +95,7 @@ gjs_throw_valist(JSContext       *context,
     if (!new_exc)
         goto out;
 
-    if (error_name != NULL) {
+    if (error_name) {
         const GjsAtoms& atoms = GjsContextPrivate::atoms(context);
         JS::RootedValue name_value(context);
         if (!gjs_string_from_utf8(context, error_name, &name_value) ||
