@@ -21,9 +21,11 @@
  * IN THE SOFTWARE.
  */
 
-#include <config.h>  // for ENABLE_PROFILER, HAVE_SYS_SYSCALL_H, HAVE_UNISTD_H
+#include <config.h>  // for ENABLE_PROFILER, HAVE_SYS_SYSCALL_H, HAVE_UNISTD_H, HAVE_SYS_SIGNAL_H
 
-#include <sys/signal.h>  // for siginfo_t, sigevent, ...
+#ifdef HAVE_SYS_SIGNAL_H
+#	include <sys/signal.h>  // for siginfo_t, sigevent, ...
+#endif
 
 #include <glib-object.h>
 #include <glib.h>
@@ -291,11 +293,8 @@ _gjs_profiler_is_running(GjsProfiler *self)
 
 #ifdef ENABLE_PROFILER
 
-static void
-gjs_profiler_sigprof(int        signum,
-                     siginfo_t *info,
-                     void      *unused)
-{
+static void gjs_profiler_sigprof(int signum G_GNUC_UNUSED, siginfo_t* info,
+                                 void*) {
     GjsProfiler *self = gjs_context_get_profiler(profiling_context);
 
     g_assert(((void) "SIGPROF handler called with invalid signal info", info));
